pub enum ManagedDatabasePairCreateOutcome {
Created,
AlreadyExists,
}Expand description
Normalized outcome of creating the managed member of one verified pair.
Variants
Created
This operation created the managed database.
AlreadyExists
The managed database already existed or a concurrent creator won.